import { h } from "@stencil/core";
export class StateStepperComponent {
    constructor() {
        this.size = '';
    }
    async stepNext(currentState, stop = false) {
        const index = this.getActiveElementIndex();
        if (index < 0) {
            return;
        }
        const steps = this.getStepElements();
        if (index >= 0) {
            const prevState = steps[index].state;
            // Found a active or latest step.
            steps[index].state = !stop && !prevState ? 'active' : currentState;
            if (!stop && !!prevState && index + 1 < steps.length) {
                // Set next step active.
                steps[index + 1].state = 'active';
            }
        }
        // Return of the last step is reached.
        return (index >= steps.length - 1 &&
            steps[steps.length - 1].state &&
            steps[steps.length - 1].state !== 'active');
    }
    async resetSteps(stepIndex = 0) {
        const steps = this.getStepElements();
        if (steps.length === 0) {
            return;
        }
        for (let i = steps.length - 1; i > stepIndex; i--) {
            steps[i].state = '';
        }
        if (stepIndex >= 0 && stepIndex < steps.length) {
            if (stepIndex > 0 && !steps[stepIndex].state) {
                return;
            }
            steps[stepIndex].state = 'active';
        }
    }
    async stepBack() {
        const index = this.getActiveElementIndex();
        if (index < 0) {
            return;
        }
        const steps = this.getStepElements();
        steps[index].state = '';
        if (index - 1 >= 0) {
            steps[index - 1].state = 'active';
        }
        else {
            steps[0].state = '';
        }
    }
    getActiveElementIndex() {
        const steps = this.getStepElements();
        if (steps.length === 0) {
            return -1;
        }
        // Find step with active state.
        let activeStepIndex = steps.findIndex(s => s.state === 'active');
        if (activeStepIndex < 0) {
            // Nothing found. Find step before a unset state.
            activeStepIndex = steps.findIndex(s => s.state === '');
            activeStepIndex--;
        }
        if (activeStepIndex < 0) {
            // Nothing found. Select first step if unset or the last.
            if (!steps[0].state) {
                activeStepIndex = 0;
            }
            else {
                activeStepIndex = steps.length - 1;
            }
        }
        return activeStepIndex;
    }
    getStepElements() {
        const slot = this.el.shadowRoot.querySelector('slot');
        const childs = slot
            .assignedElements()
            .filter(node => node.nodeName === 'STATE-STEPPER-STEP');
        return childs;
    }
    render() {
        return (h("div", { class: `wrapper ${this.size}` },
            h("slot", null)));
    }
    static get is() { return "state-stepper"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() { return {
        "$": ["state-stepper.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["state-stepper.css"]
    }; }
    static get properties() { return {
        "size": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "size",
            "reflect": false,
            "defaultValue": "''"
        }
    }; }
    static get methods() { return {
        "stepNext": {
            "complexType": {
                "signature": "(currentState: string, stop?: boolean) => Promise<boolean>",
                "parameters": [{
                        "tags": [],
                        "text": ""
                    }, {
                        "tags": [],
                        "text": ""
                    }],
                "references": {
                    "Promise": {
                        "location": "global"
                    }
                },
                "return": "Promise<boolean>"
            },
            "docs": {
                "text": "",
                "tags": []
            }
        },
        "resetSteps": {
            "complexType": {
                "signature": "(stepIndex?: number) => Promise<void>",
                "parameters": [{
                        "tags": [],
                        "text": ""
                    }],
                "references": {
                    "Promise": {
                        "location": "global"
                    }
                },
                "return": "Promise<void>"
            },
            "docs": {
                "text": "",
                "tags": []
            }
        },
        "stepBack": {
            "complexType": {
                "signature": "() => Promise<void>",
                "parameters": [],
                "references": {
                    "Promise": {
                        "location": "global"
                    }
                },
                "return": "Promise<void>"
            },
            "docs": {
                "text": "",
                "tags": []
            }
        }
    }; }
    static get elementRef() { return "el"; }
}
