import { r as registerInstance, h, g as getElement } from './core-314b7b85.js';

const StateStepperComponent = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.size = '';
    }
    async stepNext(currentState, stop = false) {
        const index = this.getActiveElementIndex();
        if (index < 0) {
            return;
        }
        const steps = this.getStepElements();
        if (index >= 0) {
            const prevState = steps[index].state;
            // Found a active or latest step.
            steps[index].state = !stop && !prevState ? 'active' : currentState;
            if (!stop && !!prevState && index + 1 < steps.length) {
                // Set next step active.
                steps[index + 1].state = 'active';
            }
        }
        // Return of the last step is reached.
        return (index >= steps.length - 1 &&
            steps[steps.length - 1].state &&
            steps[steps.length - 1].state !== 'active');
    }
    async resetSteps(stepIndex = 0) {
        const steps = this.getStepElements();
        if (steps.length === 0) {
            return;
        }
        for (let i = steps.length - 1; i > stepIndex; i--) {
            steps[i].state = '';
        }
        if (stepIndex >= 0 && stepIndex < steps.length) {
            if (stepIndex > 0 && !steps[stepIndex].state) {
                return;
            }
            steps[stepIndex].state = 'active';
        }
    }
    async stepBack() {
        const index = this.getActiveElementIndex();
        if (index < 0) {
            return;
        }
        const steps = this.getStepElements();
        steps[index].state = '';
        if (index - 1 >= 0) {
            steps[index - 1].state = 'active';
        }
        else {
            steps[0].state = '';
        }
    }
    getActiveElementIndex() {
        const steps = this.getStepElements();
        if (steps.length === 0) {
            return -1;
        }
        // Find step with active state.
        let activeStepIndex = steps.findIndex(s => s.state === 'active');
        if (activeStepIndex < 0) {
            // Nothing found. Find step before a unset state.
            activeStepIndex = steps.findIndex(s => s.state === '');
            activeStepIndex--;
        }
        if (activeStepIndex < 0) {
            // Nothing found. Select first step if unset or the last.
            if (!steps[0].state) {
                activeStepIndex = 0;
            }
            else {
                activeStepIndex = steps.length - 1;
            }
        }
        return activeStepIndex;
    }
    getStepElements() {
        const slot = this.el.shadowRoot.querySelector('slot');
        const childs = slot
            .assignedElements()
            .filter(node => node.nodeName === 'STATE-STEPPER-STEP');
        return childs;
    }
    render() {
        return (h("div", { class: `wrapper ${this.size}` }, h("slot", null)));
    }
    get el() { return getElement(this); }
    static get style() { return ":host .wrapper{text-align:center;padding:10px 0;overflow:auto;white-space:nowrap;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;font-family:Arial,Helvetica,sans-serif;-webkit-box-sizing:border-box;box-sizing:border-box}:host .large ::slotted(state-stepper-step){--size:120px}:host .small ::slotted(state-stepper-step){--size:40px}"; }
};

const StateStepperStepComponent = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.state = '';
    }
    watchHandler(newValue) {
        if (newValue === 'active') {
            this.scrollToMe();
        }
    }
    scrollToMe() {
        setTimeout(() => {
            this.el.scrollIntoView({
                behavior: 'smooth',
                block: 'center',
                inline: 'center'
            });
        });
    }
    componentDidLoad() {
        if (this.state === 'active') {
            this.scrollToMe();
        }
    }
    getStepStateClassName() {
        return this.state;
    }
    render() {
        return (h("div", { class: 'wrapper ' + this.getStepStateClassName() }, h("div", { class: "icon-wrapper" }, h("div", { class: "ani-wrapper" }, h("div", { class: "icon" }, h("slot", { name: "icon" })))), h("div", { class: "text" }, h("slot", { name: "text" }))));
    }
    get el() { return getElement(this); }
    static get watchers() { return {
        "state": ["watchHandler"]
    }; }
    static get style() { return ":host{--size:60px;--color-idle:#989aa2;--color-idle-contrast:#fff;--color-success:#10dc60;--color-success-contrast:#fff;--color-warning:#ffce00;--color-warning-contrast:#fff;--color-danger:#f04141;--color-danger-contrast:#fff;--color-active:#3880ff;--color-active-contrast:#fff;display:inline-block;position:relative;width:calc(var(--size) * 1.33);vertical-align:top;text-align:center}:host .wrapper .icon-wrapper{position:relative;width:var(--size);height:var(--size);margin:0 auto}:host .wrapper .icon-wrapper .ani-wrapper{width:100%;height:100%}:host .wrapper .icon-wrapper .ani-wrapper .icon{width:100%;height:100%;padding:20%;-o-object-fit:contain;object-fit:contain;background-color:var(--color-idle);color:var(--color-idle-contrast);border-radius:50%;-webkit-transform:scale(.67);transform:scale(.67);-webkit-transition:all .3s ease-out;transition:all .3s ease-out;will-change:transform;-webkit-box-sizing:border-box;box-sizing:border-box}:host .wrapper .icon-wrapper .ani-wrapper .icon ::slotted(*){width:100%;height:100%}:host .wrapper .icon-wrapper:before{display:block;position:absolute;z-index:-1;content:\"\";background-color:var(--color-idle);top:50%;left:50%;width:150%;height:calc(var(--size) / 10);margin-top:calc(var(--size) / -20);will-change:background-color}:host .wrapper .icon-wrapper:before,:host .wrapper .text{-webkit-transition:all .3s ease-out;transition:all .3s ease-out}:host .wrapper .text{opacity:.5;will-change:opacity;margin:5px;font-size:.8em;overflow-wrap:break-word;white-space:normal}:host .wrapper.active .text{opacity:1}:host .wrapper.active .icon-wrapper .ani-wrapper{-webkit-animation:active 1s ease-in-out .3s infinite;animation:active 1s ease-in-out .3s infinite}:host .wrapper.active .icon-wrapper .ani-wrapper .icon{-webkit-transform:scale(1);transform:scale(1);background-color:var(--color-active);color:var(--color-active-contrast)}:host .wrapper.danger .icon-wrapper .ani-wrapper{-webkit-animation:danger .6s ease-in-out .3s;animation:danger .6s ease-in-out .3s}:host .wrapper.danger .icon-wrapper .ani-wrapper .icon{background-color:var(--color-danger);color:var(--color-danger-contrast)}:host .wrapper.danger .icon-wrapper:before{background-color:var(--color-danger)}:host .wrapper.warning .icon-wrapper .ani-wrapper{-webkit-animation:warn 1s ease-in-out .3s;animation:warn 1s ease-in-out .3s}:host .wrapper.warning .icon-wrapper .ani-wrapper .icon{background-color:var(--color-warning);color:var(--color-warning-contrast)}:host .wrapper.warning .icon-wrapper:before{background-color:var(--color-warning)}:host .wrapper.success .icon-wrapper .ani-wrapper{-webkit-animation:success 1s .3s;animation:success 1s .3s}:host .wrapper.success .icon-wrapper .ani-wrapper .icon{background-color:var(--color-success);color:var(--color-success-contrast)}:host .wrapper.success .icon-wrapper:before{background-color:var(--color-success)}:host(:last-of-type) .wrapper{margin-right:0}:host(:last-of-type) .wrapper .icon-wrapper:before{display:none}\@-webkit-keyframes active{0%{-webkit-transform:scaleX(1);transform:scaleX(1)}50%{-webkit-transform:scale3d(.9,.9,.9);transform:scale3d(.9,.9,.9)}to{-webkit-transform:scaleX(1);transform:scaleX(1)}}\@keyframes active{0%{-webkit-transform:scaleX(1);transform:scaleX(1)}50%{-webkit-transform:scale3d(.9,.9,.9);transform:scale3d(.9,.9,.9)}to{-webkit-transform:scaleX(1);transform:scaleX(1)}}\@-webkit-keyframes danger{0%{-webkit-transform:translateX(0);transform:translateX(0)}10%{-webkit-transform:translateX(-6px) rotateY(-9deg);transform:translateX(-6px) rotateY(-9deg)}20%{-webkit-transform:translateX(5px) rotateY(7deg);transform:translateX(5px) rotateY(7deg)}30%{-webkit-transform:translateX(-4px) rotateY(-6deg);transform:translateX(-4px) rotateY(-6deg)}40%{-webkit-transform:translateX(3px) rotateY(5deg);transform:translateX(3px) rotateY(5deg)}50%{-webkit-transform:translateX(-2px) rotateY(-4deg);transform:translateX(-2px) rotateY(-4deg)}60%{-webkit-transform:translateX(1px) rotateY(3deg);transform:translateX(1px) rotateY(3deg)}70%{-webkit-transform:translateX(0);transform:translateX(0)}}\@keyframes danger{0%{-webkit-transform:translateX(0);transform:translateX(0)}10%{-webkit-transform:translateX(-6px) rotateY(-9deg);transform:translateX(-6px) rotateY(-9deg)}20%{-webkit-transform:translateX(5px) rotateY(7deg);transform:translateX(5px) rotateY(7deg)}30%{-webkit-transform:translateX(-4px) rotateY(-6deg);transform:translateX(-4px) rotateY(-6deg)}40%{-webkit-transform:translateX(3px) rotateY(5deg);transform:translateX(3px) rotateY(5deg)}50%{-webkit-transform:translateX(-2px) rotateY(-4deg);transform:translateX(-2px) rotateY(-4deg)}60%{-webkit-transform:translateX(1px) rotateY(3deg);transform:translateX(1px) rotateY(3deg)}70%{-webkit-transform:translateX(0);transform:translateX(0)}}\@-webkit-keyframes success{0%,to{-webkit-transform:scaleX(1);transform:scaleX(1)}30%{-webkit-transform:scale3d(1.2,.8,1);transform:scale3d(1.2,.8,1)}40%{-webkit-transform:scale3d(.8,1.2,1);transform:scale3d(.8,1.2,1)}50%{-webkit-transform:scale3d(1.1,.9,1);transform:scale3d(1.1,.9,1)}65%{-webkit-transform:scale3d(.98,1.02,1);transform:scale3d(.98,1.02,1)}75%{-webkit-transform:scale3d(1.02,.98,1);transform:scale3d(1.02,.98,1)}}\@keyframes success{0%,to{-webkit-transform:scaleX(1);transform:scaleX(1)}30%{-webkit-transform:scale3d(1.2,.8,1);transform:scale3d(1.2,.8,1)}40%{-webkit-transform:scale3d(.8,1.2,1);transform:scale3d(.8,1.2,1)}50%{-webkit-transform:scale3d(1.1,.9,1);transform:scale3d(1.1,.9,1)}65%{-webkit-transform:scale3d(.98,1.02,1);transform:scale3d(.98,1.02,1)}75%{-webkit-transform:scale3d(1.02,.98,1);transform:scale3d(1.02,.98,1)}}\@-webkit-keyframes warn{0%,10%,to{-webkit-transform:translateZ(0);transform:translateZ(0)}20%{-webkit-transform:skewX(-12deg) skewY(-12deg);transform:skewX(-12deg) skewY(-12deg)}30%{-webkit-transform:skewX(6deg) skewY(6deg);transform:skewX(6deg) skewY(6deg)}40%{-webkit-transform:skewX(-3deg) skewY(-3deg);transform:skewX(-3deg) skewY(-3deg)}50%{-webkit-transform:skewX(1.5deg) skewY(1.5deg);transform:skewX(1.5deg) skewY(1.5deg)}60%{-webkit-transform:skewX(-.8deg) skewY(-.8deg);transform:skewX(-.8deg) skewY(-.8deg)}70%{-webkit-transform:skewX(.4deg) skewY(.4deg);transform:skewX(.4deg) skewY(.4deg)}80%{-webkit-transform:skewX(-.2deg) skewY(-.2deg);transform:skewX(-.2deg) skewY(-.2deg)}}\@keyframes warn{0%,10%,to{-webkit-transform:translateZ(0);transform:translateZ(0)}20%{-webkit-transform:skewX(-12deg) skewY(-12deg);transform:skewX(-12deg) skewY(-12deg)}30%{-webkit-transform:skewX(6deg) skewY(6deg);transform:skewX(6deg) skewY(6deg)}40%{-webkit-transform:skewX(-3deg) skewY(-3deg);transform:skewX(-3deg) skewY(-3deg)}50%{-webkit-transform:skewX(1.5deg) skewY(1.5deg);transform:skewX(1.5deg) skewY(1.5deg)}60%{-webkit-transform:skewX(-.8deg) skewY(-.8deg);transform:skewX(-.8deg) skewY(-.8deg)}70%{-webkit-transform:skewX(.4deg) skewY(.4deg);transform:skewX(.4deg) skewY(.4deg)}80%{-webkit-transform:skewX(-.2deg) skewY(-.2deg);transform:skewX(-.2deg) skewY(-.2deg)}}"; }
};

export { StateStepperComponent as state_stepper, StateStepperStepComponent as state_stepper_step };
